@@ -2,7 +2,7 @@ import json
 import unittest
 
 from factual import Factual
-from factual.utils import circle
+from factual.utils import circle, point
 from test_settings import KEY, SECRET
 
 class FactualAPITestSuite(unittest.TestCase):
@@ -99,6 +99,13 @@ class FactualAPITestSuite(unittest.TestCase):
         self.assertEqual(15, payload['response']['included_rows'])
         self.assertTrue(all(row['name'] == 'Starbucks' for row in data))
 
+    def test_raw_read_with_map(self):
+        response = self.factual.raw_read('t/places/read', {'limit':15,'filters':{"name":"Starbucks"}})
+        payload = json.loads(response)
+        data = payload['response']['data']
+        self.assertEqual(15, payload['response']['included_rows'])
+        self.assertTrue(all(row['name'] == 'Starbucks' for row in data))
+
     def test_facets1(self):
         q = self.facets.search("starbucks").select("country")
         results = q.data()['country']
@@ -118,6 +125,28 @@ class FactualAPITestSuite(unittest.TestCase):
         self.assertTrue(category['shopping'] > 1000)
         self.assertTrue(category['health & medicine > physicians'] > 1000)
 
+    def test_geopulse(self):
+        geopulse = self.factual.geopulse(point(34.06021, -118.41828))
+        income_only = geopulse.select('income')
+        all_results = geopulse.data()[0]
+        income_results = income_only.data()[0]
+        self.assertIn('commercial_density', all_results)
+        self.assertTrue(0 <= all_results['commercial_density'] <= 1)
+        self.assertEqual(1, len(income_results))
+        self.assertIn('income', income_results)
+
+    def test_geocode(self):
+        geocode = self.factual.geocode(point(34.06021, -118.41828))
+        result = geocode.data()[0]
+        self.assertEqual('1801 Avenue Of The Stars', result['address'])
+        self.assertLess(result['$distance'], 20)
+
+    def test_monetize(self):
+        monetize = self.factual.monetize().filters({'place_locality':'Los Angeles'})
+        result = monetize.data()
+        self.assertGreaterEqual(len(result), 1)
+        self.assertTrue(all(row['place_locality'] == 'Los Angeles' for row in result))
+
 #    def test_submit_without_id(self):
 #        values = {'name': 'factual', 'locality': 'los angeles', 'address': '1801 Ave of the Stars'}
 #        submit = self.factual.submit('global', values=values).user('python_driver_tester')
